<?php

namespace Teknisa\SUP\Modules\Parametros\Services;

use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Sup03501ParametrizacaoAcordoFornecedorService
{
    protected $connection;
    
    public function __construct($conection, $environment)
    {
        $this->connection = $conection;
        $this->environment = $environment;
    }
    
    /********************
     *      SELECTS     *
     * ******************/
    
    public function selectCdgrupprod()
    {
        $param = [ 
            "P_CDFILIALLOGADA" => $this->environment->getCdFilial(),
        ];
        
        $query = "SELECT
                    PARASUPRI.CDGRUPPROD
                FROM
                    FILIAL,
                    PARASUPRI
                WHERE
                    FILIAL.CDFILIAL = :P_CDFILIALLOGADA
                    AND PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    private function strPadRigthProd($value){
	    return str_pad($value, 20, 'Z', STR_PAD_RIGHT);
	}

    public function selectAtualizacao($row)
    {
         $params = [ 
            'P_CDFORNORIG' => $row['CDFORNECED'],
            'P_CDPRODINI'  => $row['CDPRODINI'],
            'P_CDPRODFIN'  => $row['CDPRODFIN'] = self::strPadRightProd($row['CDPRODFIN']),
            'P_TCDPRODUTO' => $row['TCDPRODUTO'],
            'P_CDFILIAL'   => $row['CDFILIAL'],
            'P_CDGRUPPROD' => $row['CDGRUPPROD'],
            'P_CDSUBGRPROD' => $row['CDSUBGRPROD'],
            'P_DATAINIORIG' => $row['DATAINIORIG'],
            'P_DATAFINORIG' => $row['DATAFINORIG'],
            'P_NRCOTACAOORIG' => $row['NRCOTACAOORIG'],
            'P_TNRCOTACAOORIG' =>$row['TNRCOTACAOORIG'],
            'P_CDFORNDEST' => $row['CDFORNECEDDEST'],
        ];
        
        $query = "SELECT
                  CDFILIAL, CDPRODUTO, CDFORNECED,
                  CDSUBGRPROD, CDFILCOTA, NRCOLEPRECO
                FROM
                  PARTFILI
                WHERE
                    CDFORNECED = :P_CDFORNORIG
                AND (CDPRODUTO IN (SELECT CDPRODUTO
                                   FROM PRODUTO
                                   WHERE CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN) OR (:P_TCDPRODUTO = 'T'))
                AND ((INSTR(:P_CDFILIAL, CDFILIAL) > 0) OR :P_CDFILIAL = 'T')
                AND CDGRUPPROD = :P_CDGRUPPROD
                AND ((INSTR(:P_CDSUBGRPROD, CDSUBGRPROD) > 0) OR :P_CDSUBGRPROD = 'T')
                AND CDTIPPART IN (4, 7)
                AND NRCOLEPRECO IN (SELECT NRCOLEPRECO
                                    FROM COLETAPR
                                    WHERE COLETAPR.DTINIVALCOL >= :P_DATAINIORIG
                                    AND COLETAPR.DTFINVALCOL  <=  :P_DATAFINORIG
                                    AND (COLETAPR.NRCOLEPRECO = :P_NRCOTACAOORIG OR :P_TNRCOTACAOORIG = 'T'))
                AND EXISTS(SELECT PRODFORNCOMP.CDFORNECED
                           FROM PRODFORNCOMP
                           WHERE PRODFORNCOMP.CDFORNECED = :P_CDFORNDEST
                           AND PARTFILI.CDPRODUTO = PRODFORNCOMP.CDPRODCOMPL)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    // public function getCentralCompras()
    // {
    //     $param = [ 
    //         ":P_CDFILIALLOGADA" => $this->environment->getCdFilial(),
    //     ];
        
    //     $query = "SELECT
    //                 NVL(CDFILCENTCMP, CDFILIAL) CDFILCENTCMP
    //             FROM
    //                 FILIAL
    //             WHERE
    //                 CDFILIAL = :P_CDFILIALLOGADA";
    //     try {
    //         $std = $this->connection->prepare($query);
    //         $std->execute($param);
    //         return $std->fetchAll();
    //     } catch (Exception $e) {
    //         throw $e;
    //     }
    // }
    
    // public function getParametrosParasupri($cdfilcentcmp)
    // {
    //     $param = [ 
    //         ":P_CDFILCENTCMP" => $cdfilcentcmp,
    //     ];
        
    //     $query = "SELECT
    //                 CDGRUPPROD,
    //                 CDSUBGRARVOR
    //             FROM
    //                 PARASUPRI
    //             WHERE
    //                 CDFILIAL = :P_CDFILCENTCMP";
    //     try {
    //         $std = $this->connection->prepare($query);
    //         $std->execute($param);
    //         return $std->fetchAll();
    //     } catch (Exception $e) {
    //         throw $e;
    //     }
    // }
    
     /********************
     *  DELETES           *
     * ******************/
    
    public function autoDeleteAgreement($row)
    {
        $params = [ 
            'P_CDFORNECED' => $row['CDFORNECED'],
            'P_CDPRODINI'  => $row['CDPRODINI'],
            'P_CDPRODFIN'  => $row['CDPRODFIN'] = self::strPadRigthProd($row['CDPRODFIN']),
            'P_TCDPRODUTO' => $row['TCDPRODUTO'],
            'P_CDFILIAL'   => $row['CDFILIAL'],
            'P_CDGRUPPROD' => $row['CDGRUPPROD'],
            'P_CDSUBGRPROD' => $row['CDSUBGRPROD'],
            'P_DATAINIORIG' => $row['DATAINIORIG'],
            'P_DATAFINORIG' => $row['DATAFINORIG'],
            'P_NRCOTACAOORIG' => $row['NRCOTACAOORIG'],
            'P_TNRCOTACAOORIG' =>$row['TNRCOTACAOORIG'],
        ];
        
        $query = "DELETE FROM
                   PARTFILI
                WHERE
                    CDFORNECED = :P_CDFORNECED
                AND (CDPRODUTO IN (SELECT CDPRODUTO
                                   FROM PRODUTO
                                   WHERE CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN) OR (:P_TCDPRODUTO = 'T'))
                AND ((INSTR(:P_CDFILIAL, CDFILIAL) > 0) OR :P_CDFILIAL = 'T')
                AND (CDGRUPPROD = :P_CDGRUPPROD)
                AND ((INSTR(:P_CDSUBGRPROD, CDSUBGRPROD) > 0) OR :P_CDSUBGRPROD = 'T')
                AND CDTIPPART IN (4, 7)
                AND NRCOLEPRECO IN (SELECT NRCOLEPRECO
                                    FROM COLETAPR
                                    WHERE DTINIVALCOL >= :P_DATAINIORIG
                                    AND DTFINVALCOL   <=  :P_DATAFINORIG
                                    AND (NRCOLEPRECO = :P_NRCOTACAOORIG OR :P_TNRCOTACAOORIG = 'T'))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function deleteAtualizacao($item, $cdgrupprod)
    {
        $params = [ 
            'P_CDFILIAL'   => $item['CDFILIAL'],
            'P_CDPRODUTO' => $item['CDPRODUTO'],
            'P_CDFORNECED' => $item['CDFORNECED'],
            'P_CDGRUPPROD' => $cdgrupprod,
            'P_CDSUBGRPROD' => $item['CDSUBGRPROD'],
        ];
        $query = "DELETE FROM PARTFILI
                     WHERE
                CDFILIAL = :P_CDFILIAL AND
                CDPRODUTO = :P_CDPRODUTO AND
                CDFORNECED = :P_CDFORNECED AND
                CDTIPPART IN (4, 7) AND
                ((CDGRUPPROD = :P_CDGRUPPROD AND
                CDSUBGRPROD = :P_CDSUBGRPROD) OR CDGRUPPROD||CDSUBGRPROD IS NULL)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /********************
     *  INSERTS         *
     * ******************/
    
    public function insertAtualizacao($item, $row)
    {
      
        $params = [ 
            'P_CDFILIAL'   => $item['CDFILIAL'],
            'P_CDPRODUTO' => $item['CDPRODUTO'],
            'P_CDFORNECED' => $row['CDFORNECED'],
            'P_CDGRUPPROD' => $row['CDGRUPPROD'],
            'P_CDSUBGRPROD' => $item['CDSUBGRPROD'],
            'P_CDFILCOTA' => $item['CDFILCOTA'],
            'P_NRCOLEPRECO' => $row['NRCOLEPRECONOVA'],
        ];
        $query = "INSERT INTO PARTFILI(CDFILIAL, CDPRODUTO, CDTIPPART, NRSEQPART, CDFORNECED, CDFILISUBGR, CDGRUPPROD, CDSUBGRPROD, CDFILCOTA, 
                    NRCOLEPRECO)
                    (SELECT
                        :P_CDFILIAL,
                        :P_CDPRODUTO,
                        '4',
                        '1',
                        :P_CDFORNECED,
                        'P',
                        :P_CDGRUPPROD,
                        :P_CDSUBGRPROD,
                        :P_CDFILCOTA, 
                        :P_NRCOLEPRECO
                     FROM
                        PARAMGERAL
                     WHERE
                        NOT EXISTS(SELECT PARTFILI.CDFORNECED
                                   FROM PARTFILI
                                   WHERE
                                      PARTFILI.CDPRODUTO = :P_CDPRODUTO AND
                                      PARTFILI.CDFILIAL = :P_CDFILIAL AND
                                      PARTFILI.CDTIPPART IN (4, 7) ))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    
    /********************
     *      PROCEDURE     *
     * ******************/
    
    
    public function procedureSaveAgreement($row)
    {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'GRAVA_PARAMPRODSUP');
        $procedure->addParam(new Param('P_OPERACAO',        Param::PARAM_INPUT, $row['OPERACAO'],           Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQPARPROD',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIAL',        Param::PARAM_INPUT, $row['CDFILIAL'],           Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTO',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED',      Param::PARAM_INPUT, $row['CDFORNECED'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILICTRL',      Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIOPELOG',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDFILINEGREG',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDFILINEGCOR',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDPRODWEB',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCOLEPRECO',     Param::PARAM_INPUT, $row['NRCOLEPRECO'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILCOLETA',     Param::PARAM_INPUT, $row['CDFILCOLETA'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',        Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPPROD',      Param::PARAM_INPUT, $row['CDGRUPPROD'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSUBGRPROD',     Param::PARAM_INPUT, $row['CDSUBGRPROD'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILISUBGR',     Param::PARAM_INPUT, $row['CDFILISUBGR'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDACORDOFORN',    Param::PARAM_INPUT, $row['IDACORDOFORN'],       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILCOTA',       Param::PARAM_INPUT, $row['CDFILCOTA'],          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDOPERLOG',       Param::PARAM_INPUT, $row['IDOPERLOG'],          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RESULTADO',       Param::PARAM_OUTPUT, null,                      Param::PARAM_TYPE_STR, 10));
        
        
        return $procedure->execute();
    }
    
}